output_levels_ll

Function output_levels_ll 

pub fn output_levels_ll() -> u32
Low-level function to read the current output levels of all dedicated GPIO channels.

The returned value is a bitmask where each bit represents the output level of a channel: bit 0 -> channel 0, bit 1 -> channel 1, etc. A bit value of 1 means the channel output is high.