read_all_ll

Function read_all_ll 

pub fn read_all_ll() -> u32
Low-level function to read the current state of all dedicated input channels.

The returned value is a bitmask where each bit represents the state of a channel. Bit 0 represents channel 0, bit 1 represents channel 1, etc.