DedicatedGpioChannel

Struct DedicatedGpioChannel 

pub struct DedicatedGpioChannel<'lt, const CH: u8> {
    pub input: DedicatedGpioInputChannel<'lt, CH>,
    pub output: DedicatedGpioOutputChannel<'lt, CH>,
}
A single dedicated GPIO channel, both input and output.

You can split the channel by moving its fields out into separate input/output channel variables.

Fields

input: DedicatedGpioInputChannel<'lt, CH>

Channel input

output: DedicatedGpioOutputChannel<'lt, CH>

Channel output

Implementations

Source

impl<const CH: u8> DedicatedGpioChannel<'_, CH>

pub unsafe fn steal() -> Self

Conjures a new dedicated GPIO channel out of thin air.

Safety

The DedicatedGpio struct must be initialized before this function is called. There should only be one reference to the channel in use at one time.