DedicatedGpioInputChannel

Struct DedicatedGpioInputChannel 

pub struct DedicatedGpioInputChannel<'lt, const CH: u8> { /* private fields */ }
A single dedicated GPIO input channel.

Implementations

Source

impl<const CH: u8> DedicatedGpioInputChannel<'_, CH>

pub unsafe fn steal() -> Self

Conjures a new dedicated GPIO input channel out of thin air.

Safety

The DedicatedGpio struct must be initialized before this function is called. There should only be one reference to the channel in use at one time.