DedicatedGpioOutputChannel

Struct DedicatedGpioOutputChannel 

pub struct DedicatedGpioOutputChannel<'lt, const CH: u8> { /* private fields */ }
A single dedicated GPIO output channel.

Implementations

Source

impl<const CH: u8> DedicatedGpioOutputChannel<'_, CH>

pub unsafe fn steal() -> Self

Conjures a new dedicated GPIO output channel out of thin air.

Safety

The DedicatedGpio struct must be initialized before this function is called. There should only be one reference to the channel in use at one time.