pub struct DedicatedGpioInputChannel<'lt, const CH: u8> { /* private fields */ }Expand description
A single dedicated GPIO input channel.
Implementations
Sourceimpl<const CH: u8> DedicatedGpioInputChannel<'_, CH>
impl<const CH: u8> DedicatedGpioInputChannel<'_, CH>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Conjures a new dedicated GPIO input channel out of thin air.
Safety
The DedicatedGpio struct must be initialized before this function is called. There
should only be one reference to the channel in use at one time.