pub struct DedicatedGpioOutputChannel<'lt, const CH: u8> { /* private fields */ }Expand description
A single dedicated GPIO output channel.
Implementations
Sourceimpl<const CH: u8> DedicatedGpioOutputChannel<'_, CH>
impl<const CH: u8> DedicatedGpioOutputChannel<'_, CH>
Sourcepub unsafe fn steal() -> Self
pub unsafe fn steal() -> Self
Conjures a new dedicated GPIO output channel out of thin air.
Safety
The DedicatedGpio struct must be initialized before this function is called. There
should only be one reference to the channel in use at one time.