pub trait InputDriver: Sealed { }Expand description
Marker trait for GPIO input drivers.
Implementors
impl InputDriver for &mut Flex<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl InputDriver for &mut Input<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl InputDriver for Flex<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl InputDriver for Input<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.