pub trait OutputDriver: Sealed { }Expand description
Marker trait for GPIO output drivers.
Implementors
impl OutputDriver for &mut Flex<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl OutputDriver for &mut Output<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl OutputDriver for Flex<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
impl OutputDriver for Output<'_>
unstable only.Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.